@@ -7,7 +7,11 @@ from django.db.models import fields
 
 from modeltranslation import settings as mt_settings
 from modeltranslation.utils import (
-    get_language, build_localized_fieldname, build_localized_verbose_name, resolution_order)
+    get_language,
+    build_localized_fieldname,
+    build_localized_verbose_name,
+    resolution_order,
+)
 from modeltranslation.widgets import ClearableWidgetWrapper
 
 
@@ -43,6 +47,7 @@ class NONE:
     given as a fallback or undefined value) or to mark that a nullable value
     is not yet known and needs to be computed (e.g. field default).
     """
+
     pass
 
 
@@ -64,8 +69,7 @@ def create_translation_field(model, field_name, lang, empty_value):
     field = model._meta.get_field(field_name)
     cls_name = field.__class__.__name__
     if not (isinstance(field, SUPPORTED_FIELDS) or cls_name in mt_settings.CUSTOM_FIELDS):
-        raise ImproperlyConfigured(
-            '%s is not supported by modeltranslation.' % cls_name)
+        raise ImproperlyConfigured('%s is not supported by modeltranslation.' % cls_name)
     translation_class = field_factory(field.__class__)
     return translation_class(translated_field=field, language=lang, empty_value=empty_value)
 
@@ -98,6 +102,7 @@ class TranslationField(object):
     The translation field needs to know which language it contains therefore
     that needs to be specified when the field is created.
     """
+
     def __init__(self, translated_field, language, empty_value, *args, **kwargs):
         from modeltranslation.translator import translator
 
@@ -155,6 +160,7 @@ class TranslationField(object):
         # ForeignKey support - rewrite related_name
         if not NEW_RELATED_API and self.rel and self.related and not self.rel.is_hidden():
             import copy
+
             current = self.related.get_accessor_name()
             self.rel = copy.copy(self.rel)  # Since fields cannot share the same rel object.
             # self.related doesn't need to be copied, as it will be recreated in
@@ -163,7 +169,8 @@ class TranslationField(object):
             if self.rel.related_name is None:
                 # For implicit related_name use different query field name
                 loc_related_query_name = build_localized_fieldname(
-                    self.related_query_name(), self.language)
+                    self.related_query_name(), self.language
+                )
                 self.related_query_name = lambda: loc_related_query_name
             self.rel.related_name = build_localized_fieldname(current, self.language)
             self.rel.field = self  # Django 1.6
@@ -171,6 +178,7 @@ class TranslationField(object):
                 del self.rel.to._meta._related_objects_cache
         elif NEW_RELATED_API and self.remote_field and not self.remote_field.is_hidden():
             import copy
+
             current = self.remote_field.get_accessor_name()
             # Since fields cannot share the same rel object:
             self.remote_field = copy.copy(self.remote_field)
@@ -178,7 +186,8 @@ class TranslationField(object):
             if self.remote_field.related_name is None:
                 # For implicit related_name use different query field name
                 loc_related_query_name = build_localized_fieldname(
-                    self.related_query_name(), self.language)
+                    self.related_query_name(), self.language
+                )
                 self.related_query_name = lambda: loc_related_query_name
             self.remote_field.related_name = build_localized_fieldname(current, self.language)
             self.remote_field.field = self  # Django 1.6
@@ -192,8 +201,9 @@ class TranslationField(object):
     # http://docs.python.org/2.7/reference/datamodel.html#object.__hash__
     def __eq__(self, other):
         if isinstance(other, fields.Field):
-            return (self.creation_counter == other.creation_counter and
-                    self.language == getattr(other, 'language', None))
+            return self.creation_counter == other.creation_counter and self.language == getattr(
+                other, 'language', None
+            )
         return super(TranslationField, self).__eq__(other)
 
     def __ne__(self, other):
@@ -229,15 +239,19 @@ class TranslationField(object):
         if isinstance(formfield, forms.CharField):
             if self.empty_value is None:
                 from modeltranslation.forms import NullCharField
+
                 form_class = formfield.__class__
                 kwargs['form_class'] = type(
-                    'Null%s' % form_class.__name__, (NullCharField, form_class), {})
+                    'Null%s' % form_class.__name__, (NullCharField, form_class), {}
+                )
                 formfield = super(TranslationField, self).formfield(*args, **kwargs)
             elif self.empty_value == 'both':
                 from modeltranslation.forms import NullableField
+
                 form_class = formfield.__class__
                 kwargs['form_class'] = type(
-                    'Nullable%s' % form_class.__name__, (NullableField, form_class), {})
+                    'Nullable%s' % form_class.__name__, (NullableField, form_class), {}
+                )
                 formfield = super(TranslationField, self).formfield(*args, **kwargs)
                 if isinstance(formfield.widget, (forms.TextInput, forms.Textarea)):
                     formfield.widget = ClearableWidgetWrapper(formfield.widget)
@@ -270,6 +284,7 @@ class TranslationField(object):
 
     def clone(self):
         from django.utils.module_loading import import_string
+
         name, path, args, kwargs = self.deconstruct()
         cls = import_string(path)
         return cls(*args, **kwargs)
@@ -280,12 +295,15 @@ class TranslationField(object):
         """
         # We'll just introspect the _actual_ field.
         from south.modelsinspector import introspector
+
         try:
             # Check if the field provides its own 'field_class':
             field_class = self.translated_field.south_field_triple()[0]
         except AttributeError:
-            field_class = '%s.%s' % (self.translated_field.__class__.__module__,
-                                     self.translated_field.__class__.__name__)
+            field_class = '%s.%s' % (
+                self.translated_field.__class__.__module__,
+                self.translated_field.__class__.__name__,
+            )
         args, kwargs = introspector(self)
         # That's our definition!
         return (field_class, args, kwargs)
@@ -295,8 +313,10 @@ class TranslationFieldDescriptor(object):
     """
     A descriptor used for the original translated field.
     """
-    def __init__(self, field, fallback_languages=None, fallback_value=NONE,
-                 fallback_undefined=NONE):
+
+    def __init__(
+        self, field, fallback_languages=None, fallback_value=NONE, fallback_undefined=NONE
+    ):
         """
         Stores fallback options and the original field, so we know it's name
         and default.
@@ -328,7 +348,8 @@ class TranslationFieldDescriptor(object):
         """
         if isinstance(val, fields.files.FieldFile):
             return val.name and not (
-                isinstance(undefined, fields.files.FieldFile) and val == undefined)
+                isinstance(undefined, fields.files.FieldFile) and val == undefined
+            )
         return val is not None and val != undefined
 
     def __get__(self, instance, owner):
@@ -359,8 +380,9 @@ class TranslationFieldDescriptor(object):
             # instance of attr_class, but rather None or ''.
             # Normally this case is handled in the descriptor, but since we have overridden it, we
             # must mock it up.
-            if (isinstance(self.field, fields.files.FileField) and
-                    not isinstance(default, self.field.attr_class)):
+            if isinstance(self.field, fields.files.FileField) and not isinstance(
+                default, self.field.attr_class
+            ):
                 return self.field.attr_class(instance, self.field, default)
             return default
 
@@ -370,6 +392,7 @@ class TranslatedRelationIdDescriptor(object):
     A descriptor used for the original '_id' attribute of a translated
     ForeignKey field.
     """
+
     def __init__(self, field_name, fallback_languages):
         self.field_name = field_name  # The name of the original field (excluding '_id')
         self.fallback_languages = fallback_languages
@@ -401,6 +424,7 @@ class LanguageCacheSingleObjectDescriptor(object):
     """
     A Mixin for RelatedObjectDescriptors which use current language in cache lookups.
     """
+
     accessor = None  # needs to be set on instance
 
     @property
