@@ -5,12 +5,9 @@ Settings overrided for test time
 from django.conf import settings
 
 
-INSTALLED_APPS = tuple(settings.INSTALLED_APPS) + (
-    'modeltranslation.tests',
-)
+INSTALLED_APPS = tuple(settings.INSTALLED_APPS) + ('modeltranslation.tests',)
 
-LANGUAGES = (('de', 'Deutsch'),
-             ('en', 'English'))
+LANGUAGES = (('de', 'Deutsch'), ('en', 'English'))
 LANGUAGE_CODE = 'de'
 MODELTRANSLATION_DEFAULT_LANGUAGE = 'de'
 
